@@ -1,7 +1,7 @@
 #!/bin/bash
 # Drupal	(http://drupal.org)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-08-28
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-28
 # require:
 #	httpd-2.2.x
 #	php-5.2.x
@@ -10,13 +10,20 @@
 
 
 wget -N http://ftp.drupal.org/files/projects/drush-All-Versions-HEAD.tar.gz
-tar xfz drush-All-Versions-HEAD.tar.gz 
+tar xvfz drush-All-Versions-HEAD.tar.gz 
 
 export PATH=/opt/php5/bin:$PATH
 
-./drush/drush dl drupal > drush-dl-drupal.log
-VERSION=`head -1 drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
+#./drush/drush dl drupal > drush-dl-drupal.log
+#VERSION=`head -1 drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
+
+VERSION=6.22
 PAC_NAME=drupal-$VERSION
+SRC_NAME=${PAC_NAME}.tar.gz
+SRC_URI=http://ftp.drupal.org/files/projects/${SRC_NAME}
+wget -N $SRC_URI
+tar xvfz $SRC_NAME
+
 (cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
 JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
 
@@ -154,10 +161,10 @@ __EOCL__
 cd $WORK
 echo "y
 1
-" | makepkg ${PAC_NAME}.tgz
+" | makepkg ${PAC_NAME}-${SYS_NAME}.tgz
 
 echo -n "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz"
-if `mv -v ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
+if `mv -v ${PAC_NAME}-${SYS_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
   echo " ... done"
 else
   echo " ... false"
